@@ -51,7 +51,7 @@ func (c *FileListChangesFileHash) UnmarshalControl(data string) error {
 	}
 
 	c.Hash = vals[0]
-	c.Size, err = strconv.Atoi(vals[1])
+	c.Size, err = strconv.ParseInt(vals[1], 10, 64)
 	if err != nil {
 		return err
 	}
@@ -98,7 +98,7 @@ type Changes struct {
 // Given a path on the filesystem, Parse the file off the disk and return
 // a pointer to a brand new Changes struct, unless error is set to a value
 // other than nil.
-func ParseDebianFile(path string) (ret *Changes, err error) {
+func ParseChangesFile(path string) (ret *Changes, err error) {
 	path, err = filepath.Abs(path)
 	if err != nil {
 		return nil, err
@@ -108,6 +108,7 @@ func ParseDebianFile(path string) (ret *Changes, err error) {
 	if err != nil {
 		return nil, err
 	}
+	defer f.Close()
 
 	ret, err = ParseChanges(bufio.NewReader(f), path)
 	if err != nil {
